# CATCH.tcl--- Oxford CATCH module control frame
#  

set frame CATCH
set frametitle "CATCH module Setup & Monitor"
set icontitle "CATCH"

set mname "CATCH"

set wrname(ACCON)      accum-on
set wrname(ACCOFF)     accum-off
set wrname(REQGRP)     req-group
set wrname(CAL)        calibrate
set wrname(CLEAR)      clear
set wrname(STOP)       stop-hsm-acq
set wrname(RESTART)    restart
set wrname(STATUS)     status

loadsource common.camac

set maxmodule [inform camaccontrol inquire [set mname]count]
set modulelist {}
for {set i 1} {$i <= $maxmodule} {incr i} {lappend modulelist $i}

set module [first $modulelist]

set reset_cmd "clear"

proc repaint {} {}

proc redisplay-module {} {
   global debug
   if {$debug} then {puts stderr "redisplay-module with arguments"}
   camac-address
}

proc do-action {w} {
    global wrname 
    :modify QX :value ""
    set qx [read-reg $wrname($w)]
    :modify QX :value $qx
}

proc do-status {} {
    :modify QX :value ""
    set reply [read-reg status]
    :modify STATUSREPLY :value $reply
}

proc click arg {
   global debug
   if {$debug} then {puts stderr "click with argument \{$arg\}"}
   set f [lindex $arg 0]
   set c [lindex $arg 1]
   set w [lindex $arg 2]
   set v [lindex $arg 3]
   if {$c==":quit"} then {click-quit; return}
   switch $w {

      ACCON   -
      ACCOFF  -
      REQGRP  -
      CAL     -
      CLEAR   -
      STOP    -
      RESTART   {do-action $w}

      STATUS    {do-status}

      default   {puts stdout $arg}
   }
}


proc make-frame {} {
  global env camcrate camstation rddata

  :frame [self frame-name] :label "[self frame-title]" :show-footer T \
      :icon-image "@$env(ICONHOME)/charissa" \
      :icon-name "[self icon-title]"

   :panel MODULE :layout T  :padx 5 :pady 5
      :layout H; :row-gap 10

      :hskip 150
      :text CAM-CRATE   :label "CAMAC Crate:"   :w 5 :value $camcrate   :deaf T
      :text CAM-STATION :label "CAMAC Station:" :w 5 :value $camstation :deaf T

      :next-row T; :col-gap 10
      :button ACCON   :label "Accumulate ON"
      :button ACCOFF  :label "Accumulate OFF"
      :button REQGRP  :label "REQ Group"
      :next-row T
      :button CAL     :label  Calibrate
      :button CLEAR   :label  Clear
      :button STOP    :label "Stop Data Acq"
      :button RESTART :label "Restart Readout"
      :next-row T
      :button STATUS      :label "Status Register" 
      :text STATUSREPLY  :label "" :w 8 :deaf T
      :next-row T
      :text  QX      :label "Last command returned QX"  :w 4 :deaf T

   :show T

}
